# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ExecutionData.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x45xecutionData.proto\x12\x08iobinary\"\xbb\x03\n\rExecutionData\x12\x32\n\x08versions\x18\x01 \x01(\x0b\x32 .iobinary.ExecutionData.Versions\x12\x36\n\nsimulation\x18\x02 \x01(\x0b\x32\".iobinary.ExecutionData.Simulation\x12<\n\rconfiguration\x18\x03 \x01(\x0b\x32%.iobinary.ExecutionData.Configuration\x1ak\n\x08Versions\x12\x14\n\x0c\x66\x61meProtobuf\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61meIo\x18\x02 \x01(\t\x12\x10\n\x08\x66\x61meCore\x18\x03 \x01(\t\x12\x0e\n\x06python\x18\x04 \x01(\t\x12\x0b\n\x03jvm\x18\x05 \x01(\t\x12\n\n\x02os\x18\x06 \x01(\t\x1a@\n\nSimulation\x12\r\n\x05start\x18\x01 \x01(\t\x12\x14\n\x0c\x64urationInMS\x18\x02 \x01(\x03\x12\r\n\x05ticks\x18\x03 \x01(\x03\x1aQ\n\rConfiguration\x12\x11\n\tcoreCount\x18\x01 \x01(\x05\x12\x15\n\routputProcess\x18\x02 \x01(\x05\x12\x16\n\x0eoutputInterval\x18\x03 \x01(\x05\x42(\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\tExecution')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ExecutionData_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\tExecution'
  _globals['_EXECUTIONDATA']._serialized_start=34
  _globals['_EXECUTIONDATA']._serialized_end=477
  _globals['_EXECUTIONDATA_VERSIONS']._serialized_start=221
  _globals['_EXECUTIONDATA_VERSIONS']._serialized_end=328
  _globals['_EXECUTIONDATA_SIMULATION']._serialized_start=330
  _globals['_EXECUTIONDATA_SIMULATION']._serialized_end=394
  _globals['_EXECUTIONDATA_CONFIGURATION']._serialized_start=396
  _globals['_EXECUTIONDATA_CONFIGURATION']._serialized_end=477
# @@protoc_insertion_point(module_scope)
