# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Services.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eServices.proto\x12\rcommunication\"!\n\rScheduledTime\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\"c\n\nProtoSetup\x12\x16\n\x0eoutputInterval\x18\x01 \x02(\x05\x12\x1e\n\x16outputActiveClassNames\x18\x02 \x03(\t\x12\x1d\n\x15outputComplexDisabled\x18\x03 \x02(\x08\"\x1f\n\rWarmUpMessage\x12\x0e\n\x06needed\x18\x01 \x02(\x08\"\xc8\x04\n\x06Output\x12\x32\n\tagentType\x18\x01 \x03(\x0b\x32\x1f.communication.Output.AgentType\x12,\n\x06series\x18\x02 \x03(\x0b\x32\x1c.communication.Output.Series\x1a\x94\x01\n\tAgentType\x12\x11\n\tclassName\x18\x01 \x02(\t\x12\x34\n\x05\x66ield\x18\x02 \x03(\x0b\x32%.communication.Output.AgentType.Field\x1a>\n\x05\x46ield\x12\x0f\n\x07\x66ieldId\x18\x01 \x02(\x05\x12\x11\n\tfieldName\x18\x02 \x02(\t\x12\x11\n\tindexName\x18\x03 \x03(\t\x1a\xc4\x02\n\x06Series\x12\x11\n\tclassName\x18\x01 \x02(\t\x12\x0f\n\x07\x61gentId\x18\x02 \x02(\x03\x12/\n\x04line\x18\x03 \x03(\x0b\x32!.communication.Output.Series.Line\x1a\xe4\x01\n\x04Line\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\x12\x38\n\x06\x63olumn\x18\x02 \x03(\x0b\x32(.communication.Output.Series.Line.Column\x1a\x8f\x01\n\x06\x43olumn\x12\x0f\n\x07\x66ieldId\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\x12;\n\x05\x65ntry\x18\x03 \x03(\x0b\x32,.communication.Output.Series.Line.Column.Map\x1a(\n\x03Map\x12\x12\n\nindexValue\x18\x01 \x03(\t\x12\r\n\x05value\x18\x02 \x02(\t\"5\n\x0b\x41\x64\x64ressBook\x12\x11\n\tprocessId\x18\x01 \x02(\x05\x12\x13\n\x07\x61gentId\x18\x02 \x03(\x03\x42\x02\x10\x01\x42\'\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x08Services')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\010Services'
  _globals['_ADDRESSBOOK'].fields_by_name['agentId']._options = None
  _globals['_ADDRESSBOOK'].fields_by_name['agentId']._serialized_options = b'\020\001'
  _globals['_SCHEDULEDTIME']._serialized_start=33
  _globals['_SCHEDULEDTIME']._serialized_end=66
  _globals['_PROTOSETUP']._serialized_start=68
  _globals['_PROTOSETUP']._serialized_end=167
  _globals['_WARMUPMESSAGE']._serialized_start=169
  _globals['_WARMUPMESSAGE']._serialized_end=200
  _globals['_OUTPUT']._serialized_start=203
  _globals['_OUTPUT']._serialized_end=787
  _globals['_OUTPUT_AGENTTYPE']._serialized_start=312
  _globals['_OUTPUT_AGENTTYPE']._serialized_end=460
  _globals['_OUTPUT_AGENTTYPE_FIELD']._serialized_start=398
  _globals['_OUTPUT_AGENTTYPE_FIELD']._serialized_end=460
  _globals['_OUTPUT_SERIES']._serialized_start=463
  _globals['_OUTPUT_SERIES']._serialized_end=787
  _globals['_OUTPUT_SERIES_LINE']._serialized_start=559
  _globals['_OUTPUT_SERIES_LINE']._serialized_end=787
  _globals['_OUTPUT_SERIES_LINE_COLUMN']._serialized_start=644
  _globals['_OUTPUT_SERIES_LINE_COLUMN']._serialized_end=787
  _globals['_OUTPUT_SERIES_LINE_COLUMN_MAP']._serialized_start=747
  _globals['_OUTPUT_SERIES_LINE_COLUMN_MAP']._serialized_end=787
  _globals['_ADDRESSBOOK']._serialized_start=789
  _globals['_ADDRESSBOOK']._serialized_end=842
# @@protoc_insertion_point(module_scope)
