# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Bundle.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import AgentMessage_pb2 as AgentMessage__pb2
from fameprotobuf import Services_pb2 as Services__pb2
from fameprotobuf import InputFile_pb2 as InputFile__pb2
from fameprotobuf import Model_pb2 as Model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x42undle.proto\x12\x03mpi\x1a\x12\x41gentMessage.proto\x1a\x0eServices.proto\x1a\x0fInputFile.proto\x1a\x0bModel.proto\"\xe4\x02\n\nMpiMessage\x12\x33\n\rscheduledTime\x18\x01 \x01(\x0b\x32\x1c.communication.ScheduledTime\x12,\n\x06warmUp\x18\x02 \x01(\x0b\x32\x1c.communication.WarmUpMessage\x12/\n\x0b\x61\x64\x64ressBook\x18\x03 \x01(\x0b\x32\x1a.communication.AddressBook\x12\"\n\x05input\x18\x04 \x01(\x0b\x32\x13.iobinary.InputData\x12%\n\x06output\x18\x05 \x01(\x0b\x32\x15.communication.Output\x12,\n\x07message\x18\x06 \x01(\x0b\x32\x1b.communication.ProtoMessage\x12(\n\x05setup\x18\x07 \x01(\x0b\x32\x19.communication.ProtoSetup\x12\x1f\n\x05model\x18\x08 \x01(\x0b\x32\x10.model.ModelData\"*\n\x06\x42undle\x12 \n\x07message\x18\x01 \x03(\x0b\x32\x0f.mpi.MpiMessageB\"\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x03Mpi')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Bundle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\003Mpi'
  _globals['_MPIMESSAGE']._serialized_start=88
  _globals['_MPIMESSAGE']._serialized_end=444
  _globals['_BUNDLE']._serialized_start=446
  _globals['_BUNDLE']._serialized_end=488
# @@protoc_insertion_point(module_scope)
