# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InputFile.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import Contract_pb2 as Contract__pb2
from fameprotobuf import Field_pb2 as Field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fInputFile.proto\x12\x08iobinary\x1a\x0e\x43ontract.proto\x1a\x0b\x46ield.proto\"\xf3\x05\n\tInputData\x12\r\n\x05runId\x18\x01 \x02(\x03\x12\x37\n\nsimulation\x18\x02 \x02(\x0b\x32#.iobinary.InputData.SimulationParam\x12\x35\n\ntimeSeries\x18\x04 \x03(\x0b\x32!.iobinary.InputData.TimeSeriesDao\x12+\n\x05\x61gent\x18\x05 \x03(\x0b\x32\x1c.iobinary.InputData.AgentDao\x12.\n\x08\x63ontract\x18\x06 \x03(\x0b\x32\x1c.communication.ProtoContract\x12\x0e\n\x06schema\x18\x08 \x01(\t\x12\x34\n\nstringSets\x18\t \x03(\x0b\x32 .iobinary.InputData.StringSetDao\x1aJ\n\x0fSimulationParam\x12\x11\n\tstartTime\x18\x01 \x02(\x03\x12\x10\n\x08stopTime\x18\x02 \x02(\x03\x12\x12\n\nrandomSeed\x18\x03 \x02(\x03\x1a\x66\n\rTimeSeriesDao\x12\x10\n\x08seriesId\x18\x01 \x02(\x05\x12\x12\n\nseriesName\x18\x02 \x01(\t\x12\x15\n\ttimeSteps\x18\x04 \x03(\x03\x42\x02\x10\x01\x12\x12\n\x06values\x18\x05 \x03(\x01\x42\x02\x10\x01J\x04\x08\x03\x10\x04\x1a\x61\n\x08\x41gentDao\x12\n\n\x02id\x18\x01 \x02(\x03\x12\x11\n\tclassName\x18\x02 \x02(\t\x12$\n\x05\x66ield\x18\x03 \x03(\x0b\x32\x15.iobinary.NestedField\x12\x10\n\x08metadata\x18\x04 \x01(\t\x1a\xa0\x01\n\x0cStringSetDao\x12\x0c\n\x04name\x18\x01 \x02(\t\x12>\n\x05value\x18\x02 \x03(\x0b\x32/.iobinary.InputData.StringSetDao.StringSetEntry\x12\x10\n\x08metadata\x18\x03 \x01(\t\x1a\x30\n\x0eStringSetEntry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08\x42$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05Input')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'InputFile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Input'
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['timeSteps']._options = None
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['timeSteps']._serialized_options = b'\020\001'
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['values']._options = None
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_INPUTDATA']._serialized_start=59
  _globals['_INPUTDATA']._serialized_end=814
  _globals['_INPUTDATA_SIMULATIONPARAM']._serialized_start=362
  _globals['_INPUTDATA_SIMULATIONPARAM']._serialized_end=436
  _globals['_INPUTDATA_TIMESERIESDAO']._serialized_start=438
  _globals['_INPUTDATA_TIMESERIESDAO']._serialized_end=540
  _globals['_INPUTDATA_AGENTDAO']._serialized_start=542
  _globals['_INPUTDATA_AGENTDAO']._serialized_end=639
  _globals['_INPUTDATA_STRINGSETDAO']._serialized_start=642
  _globals['_INPUTDATA_STRINGSETDAO']._serialized_end=802
  _globals['_INPUTDATA_STRINGSETDAO_STRINGSETENTRY']._serialized_start=754
  _globals['_INPUTDATA_STRINGSETDAO_STRINGSETENTRY']._serialized_end=802
# @@protoc_insertion_point(module_scope)
